OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} error)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "nicht teilnehmen",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neue Veranstaltung",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "EMail has been sent." : "E-Mail wurde versendet.",
    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "wenn geteilt, das ganze Ereignis anzeigen",
    "When shared show only busy" : "wenn geteilt, nur den Status beschäftigt anzeigen",
    "When shared hide this event" : "wenn geteilt, wird das Ereignis verborgen",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "abgebrochen",
    "Please add a title!" : "Bitte einen Titel hinzufügen!",
    "Please select a calendar!" : "Bitte einen Kalender auswählen!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "At time of event" : "Zum Zeitpunkt der Veranstaltung",
    "5 minutes before" : "vor 5 Minuten",
    "10 minutes before" : "vor 10 Minuten",
    "15 minutes before" : "vor 15 Minuten",
    "30 minutes before" : "vor 30 Minuten",
    "1 hour before" : "vor 1 Stunde",
    "2 hours before" : "vor 2 Stunden",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-up",
    "sec" : "s",
    "min" : "min",
    "hours" : "Stunden",
    "days" : "Tagen",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} von {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn der Veranstaltung",
    "{type} {time} before the event ends" : "{type} {time} vor Ende der Veranstaltung",
    "{type} {time} after the event starts" : "{type} {time} nachdem die Veranstaltung beginnt",
    "{type} {time} after the event ends" : "{type} {time} nachdem die Veranstaltung endet",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere Deinen Administrator für weitere Informationen.",
    "Title of the Event" : "Titel der Veranstaltung",
    "starts" : "Beginn",
    "ends" : "Ende",
    "All day Event" : "Ganztägige Veranstaltung",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr …",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Veranstaltungsstatus",
    "Visibility when sharing" : "Geteilte Ansicht",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
    "Cheers!" : "Noch einen schönen Tag!",
    "We wanted to inform you that %s has published the calendar %s." : "Wir wollen dich informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicke auf den unteren Link, um darauf zuzugreifen",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset-Pipeline-Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte den Administrator kontaktieren und ihn bitten, die Konfigurationsoption »asset-pipeline.enabled« zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfe die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender freigeben",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Verweis",
    "WebCal URL" : "WebCal-Adresse",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern und Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link freigeben",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "neues Abonnement",
    "WebCal-URL" : "WebCal-Adresse",
    "Go back" : "Zurück gehen",
    "Go forward" : "Weiter gehen",
    "Edit event" : "Veranstaltung bearbeiten",
    "Delete Event" : "Veranstaltung löschen",
    "Save Event" : "Veranstaltung speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte geben Sie Ihre E-Mail-Adresse in den Einstellungen an, um Teilnehmer hinzuzufügen.",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederholen alle …",
    "end repeat ..." : "Wiederholung beenden …",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Import abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Publish URL" : "URL veröffentlichen",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Skip simple event editor" : "Einfachen Termin-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Es wurde keine Kalenderdatei für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");
